<?php
// If this file is called directly, abort.
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * WordPress settings API demo class
 *
 * 
 */
if ( !class_exists('Epwca_All_Settings' ) ){
	class Epwca_All_Settings {
		
		//instance check property
		private static $instance;
		
		//Settings
		private $settings_api;

		public function __construct() {
			$this->settings_api = new Epwca_Settings_API;

			add_action( 'admin_init', array($this, 'admin_init') );
			add_action( 'admin_menu', array($this, 'admin_menu'),55 );
		}

		
		/**
		 * Class instance
		 *
		 * @since   1.0.0
		 */
		public static function getInstance(){
			if (null === self::$instance) {
				self::$instance = new self();
			}

			return self::$instance;
		}
		
		public function admin_init() {

			//set the settings
			$this->settings_api->set_sections( $this->get_settings_sections() );
			$this->settings_api->set_fields( $this->get_settings_fields() );

			//initialize settings
			$this->settings_api->admin_init();
		}

		public function admin_menu() {
			add_submenu_page( 'woocommerce', 'Ep Autocomplete', 'Ep Autocomplete', 'manage_options', 'ep_autocomplete_settings', array($this, 'plugin_page') );
			
		}

		public function get_settings_sections() {
			$sections = array(
				array(
					'id'    => 'epwca_general',
					'title' => __( 'General', 'epwca' )
				),
				
			);
			return $sections;
		}

		/**
		 * Returns all the settings fields
		 *
		 * @return array settings fields
		 */
		public function get_settings_fields() {
			global $woocommerce;
			$countries_obj   = new WC_Countries();
			$countries   = $countries_obj->__get('countries');
			$settings_fields = array(
				'epwca_general' => array(
					array(
						'name'    => 'epwca_gm_api_key',
						'label'   => __( 'Google API Key', 'epwca' ),
						'type'    => 'password',
						'desc'    => __( 'Enter the <a href="https://developers.google.com/places/web-service/autocomplete">Google API</a> Key.By default, google address autocomplete api usage is limited. <br> To increase the usage limit, check this <a href="https://developers.google.com/places/web-service/usage" target="_blank">article from google.</a>', 'epwca' ),
						'default' => ''
					),
					array(
						'name'              => 'epwca_billing_label',
						'label'             => __( 'Billing Field Label', 'epwca' ),
						'placeholder'       => __( 'Address Autocomplete', 'epwca' ),
						'type'              => 'text',
						'default'           => 'Address Autocomplete',
					),
					array(
						'name'              => 'epwca_shipping_label',
						'label'             => __( 'Shipping Field Label', 'epwca' ),
						'placeholder'       => __( 'Address Autocomplete', 'epwca' ),
						'type'              => 'text',
						'default'           => 'Address Autocomplete',
					),
					array(
						'name' => 'epwca_selectbox',
						'label' => __( 'Select Countries', 'epwca' ),
						'type' => 'select',
						'size' => 'regular select_countries',
						'multiple' => 'multiple',
						'default' => 'no',
						'options' => $countries
					),
				),
				
			);

			return $settings_fields;
		}

		public function plugin_page() {
			echo '<div class="wrap">';

			$this->settings_api->show_navigation();
			$this->settings_api->show_forms();

			echo '</div>';
		}

		/**
		 * Get all the pages
		 *
		 * @return array page names with key value pairs
		 */
		public function get_pages() {
			$pages = get_pages();
			$pages_options = array();
			if ( $pages ) {
				foreach ($pages as $page) {
					$pages_options[$page->ID] = $page->post_title;
				}
			}

			return $pages_options;
		}

	}//end class
	if(class_exists('Epwca_All_Settings') ){
		Epwca_All_Settings::getInstance();
	}
}

/**
* Get the value of a settings field
*
*/
if( !function_exists('epwca_get_option') ){
	function epwca_get_option( $option, $section, $default = '' ) {
	 
		$options = get_option( $section );
	 
		if ( isset( $options[$option] ) ) {
		return $options[$option];
		}
	 
		return $default;
	}
}