<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if( !class_exists('Epwca_Address_Autocomplete') ){
	class Epwca_Address_Autocomplete {

		//instance check property
		private static $instance;
		
		// labels
		public $billing_label;
		
		public $shipping_label;

		/**
		 * constructor
		 *
		 * @since   1.0.0
		 */
		public function __construct() {
			
			if(defined('WC_VERSION') && WC_VERSION < '3.0'){
				add_filter( 'woocommerce_before_checkout_billing_form', array($this,'epwca_address_autocomplete_validation_fields'));
			}else{
				add_filter( 'woocommerce_checkout_fields', array($this,'epwca_address_autocomplete_validation_fields_create'));
				add_filter( 'woocommerce_checkout_fields', array($this,'epwca_address_autocomplete_validation_fields_arrange'));
			}
			
			// label
			$this->billing_label = epwca_get_option('epwca_billing_label','epwca_general','Address Autocomplete');
			$this->shipping_label = epwca_get_option('epwca_shipping_label','epwca_general','Address Autocomplete');
		}

		/**
		 * Class instance
		 *
		 * @since   1.0.0
		 */
		public static function getInstance(){
			if (null === self::$instance) {
				self::$instance = new self();
			}

			return self::$instance;
		}

		/**
		 * to create two new address autocomplete fields in woocommerce version less than 3.0
		 *
		 * @since   1.0.0
		 */
		public function epwca_address_autocomplete_validation_fields( $checkout_fields ) {
			foreach($checkout_fields->checkout_fields['billing'] as $key=>$value)
			{
			$temp_billing_fields[$key] = $value;
			
			if($key == 'billing_phone'){
				$temp_billing_fields['billing_autocomplete'] = array(
					'label'	    => $this->billing_label,
					'placeholder'   => _x('Search for address', 'placeholder', 'woocommerce'),
					'required'	    => false,
					'class'	    => array('form-row-wide'),
					'clear'	    => true
				);
			}
			}
			$checkout_fields->checkout_fields['billing'] = $temp_billing_fields;
			
			foreach($checkout_fields->checkout_fields['shipping'] as $key=>$value)
			{
			$temp_shipping_fields[$key] = $value;
			
			if($key == 'shipping_company')
			{
				$temp_shipping_fields['shipping_autocomplete'] = array(
					'label'	    => $this->shipping_label,
					'placeholder'   => _x('Search for address', 'placeholder', 'woocommerce'),
					'required'	    => false,
					'class'	    => array('form-row-wide'),
					'clear'	    => true
				);
			}
			}
			$checkout_fields->checkout_fields['shipping'] = $temp_shipping_fields;
			 return $checkout_fields;
		}
		

		/**
		 * to create two new address autocomplete fields
		 *
		 * @since   1.0.0
		 */
		public function epwca_address_autocomplete_validation_fields_create( $fields ) {
			 $fields['billing']['billing_autocomplete'] = array(
				'label'     => $this->billing_label,
				'placeholder'   => _x('Search for address', 'placeholder', 'woocommerce'),
				'required'  => false,
				'class'     => array('form-row-wide'),
				'clear'     => true
			 );
			 $fields['shipping']['shipping_autocomplete'] = array(
				'label'     => $this->shipping_label,
				'placeholder'   => _x('Search for address', 'placeholder', 'woocommerce'),
				'required'  => false,
				'class'     => array('form-row-wide'),
				'clear'     => true
			 );
			 return $fields;
		}

		/**
		 * to rearrange the input fields
		 *
		 * bug - reshift country manually using array
		 * @since   1.0.0
		 */
		public function epwca_address_autocomplete_validation_fields_arrange( $fields ) {
			$billing_order = array(
				"billing_first_name", 
				"billing_last_name",
				"billing_company",
				"billing_autocomplete",
				"billing_email", 
				"billing_phone",
				"billing_address_1", 
				"billing_address_2", 
				"billing_city",
				"billing_state",
				"billing_postcode", 
				"billing_country"
			);
			// This sets the billing fields in the order above
			foreach($billing_order as $billing_field) {

				$billing_fields[$billing_field] = $fields["billing"][$billing_field];
				unset($fields['billing'][$billing_field]);
			}
			$remaining_fields_billing = array();
			if(!empty($fields["billing"]))
			{
				$remaining_fields_billing[]=$fields["billing"];
				$fields["billing"] = array_merge($billing_fields, $remaining_fields_billing);
			}
			else
			{
				$fields["billing"] = $billing_fields;
			}

			$shipping_order = array(
				"shipping_first_name", 
				"shipping_last_name", 
				"shipping_company", 
				"shipping_autocomplete",
				"shipping_address_1", 
				"shipping_address_2",
				"shipping_city",
				"shipping_state", 
				"shipping_postcode", 
				"shipping_country"
			);
			// This sets the shipping fields in the order above
			foreach($shipping_order as $shipping_field) {
				$shipping_fields[$shipping_field] = $fields["shipping"][$shipping_field];
				unset($fields['shipping'][$shipping_field]);
			}
			$remaining_fields_shipping = array();
			if(!empty($fields["shipping"]))
			{
				$remaining_fields_shipping[]=$fields["shipping"];
				$fields["shipping"] = array_merge($shipping_fields, $remaining_fields_shipping);
			}
			else
			{
				$fields["shipping"] = $shipping_fields;
			}
			return $fields;
		}

	}//end class
	if(class_exists('Epwca_Address_Autocomplete') ){
		Epwca_Address_Autocomplete::getInstance();
	}
}