<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/* PLUGIN ALL CSS AND JS FILES */

if( !function_exists('epwca_enqueue_files') ){
	function epwca_enqueue_files(){
		
		if ( function_exists('is_checkout') && !is_checkout() ) {
	        return;
	    }
		
		$map_api_key = epwca_get_option('epwca_gm_api_key','epwca_general','');

		if( empty($map_api_key) ){ return; }
		
		$plugin_ver = EPWCA_NAME_VERSION; // VERSION
		/* ---- PLUGIN ALL STYLES ---- */
		$all_css = array(
			// Plugins Css
			array(
				'handle' => 'geocomplete-min',
				'src' => EPWCA_PLUGIN_CSS.'/jquery.geocomplete.min.css',
				'deps' => array(),
				'version' => $plugin_ver,
				'media' => 'all',
			),
			// Main Css
			array(
				'handle' => 'epwca-main',
				'src' => EPWCA_PLUGIN_CSS.'/styles.css',
				'deps' => array('geocomplete-min'),
				'version' => $plugin_ver,
				'media' => 'all',
			),

		);

		$all_css = apply_filters( 'epwca_css_files_enqueue', $all_css );
		if ( !empty($all_css) && is_array($all_css) ){
			foreach ( $all_css as $css ){
				call_user_func_array( 'wp_enqueue_style', $css );
			}
		}
		/* ---- PLUGIN ALL JS ---- */
		$all_js = array(
			// plugins
			array(
				'handle' => 'google-maps-api',
				'src' => '//maps.googleapis.com/maps/api/js?libraries=places&key='.$map_api_key,
				'deps' => array(),
				'version' => $plugin_ver,
				'in_footer' => false,
			),
			// geocomplete 
			array(
				'handle' => 'geocomplete-min',
				'src' => EPWCA_PLUGIN_JS.'/jquery.geocomplete.min.js',
				'deps' => array('jquery','google-maps-api'),
				'version' => $plugin_ver,
				'in_footer' => true,
			),
			array(
				'handle' => 'epwca-main',
				'src' => EPWCA_PLUGIN_JS.'/scripts.js',
				'deps' => array('geocomplete-min'),
				'version' => $plugin_ver,
				'in_footer' => true,
			),
		);
		

		$all_js = apply_filters( 'epwca_js_files_enqueue', $all_js );
		
		if ( !empty($all_js) && is_array($all_js) ){
			foreach ( $all_js as $js ){
				call_user_func_array( 'wp_enqueue_script', $js );
			}
		}
		// country selection
		$select_country = epwca_get_option('epwca_selectbox','epwca_general',[]);
		wp_localize_script( 'geocomplete-min', 'epwca_country', $select_country );
	}
	add_action( 'wp_enqueue_scripts', 'epwca_enqueue_files');
} // --- End

if( !function_exists('epwca_admin_enqueue_files') ){
	function epwca_admin_enqueue_files($hook){
		
		if( 'woocommerce_page_ep_autocomplete_settings' !== $hook ){
			return;
		}
		
		$plugin_ver = EPWCA_NAME_VERSION; // VERSION
		/* ---- PLUGIN ALL STYLES ---- */
		$all_css = array(
			// Admin Css
			array(
				'handle' => 'epwca-dropdown',
				'src' => EPWCA_PLUGIN_ADMIN_CSS.'/jquery.dropdown.min.css',
				'deps' => array(),
				'version' => $plugin_ver,
				'media' => 'all',
			),

		);

		$all_css = apply_filters( 'epwca_css_files_enqueue', $all_css );
		if ( !empty($all_css) && is_array($all_css) ){
			foreach ( $all_css as $css ){
				call_user_func_array( 'wp_enqueue_style', $css );
			}
		}
		/* ---- PLUGIN ALL JS ---- */
		$all_js = array(
			array(
				'handle' => 'epwca-dropdown',
				'src' => EPWCA_PLUGIN_ADMIN_JS.'/jquery.dropdown.min.js',
				'deps' => array('jquery'),
				'version' => $plugin_ver,
				'in_footer' => true,
			),
			array(
				'handle' => 'epwca-admin',
				'src' => EPWCA_PLUGIN_ADMIN_JS.'/scripts.js',
				'deps' => array('jquery','epwca-dropdown'),
				'version' => $plugin_ver,
				'in_footer' => true,
			),
		);
		

		$all_js = apply_filters( 'epwca_js_files_enqueue', $all_js );
		
		if ( !empty($all_js) && is_array($all_js) ){
			foreach ( $all_js as $js ){
				call_user_func_array( 'wp_enqueue_script', $js );
			}
		}
		
	}
	add_action( 'admin_enqueue_scripts', 'epwca_admin_enqueue_files');
} // --- End